updt
====

A simple updater script for source files.

Usage
-----

Looks in the current directory for any ``*.py`` files containing a line in any of the following formats:

.. code:: python

    # source: https://raw.githubusercontent.com/...
    # update-source: https://raw.githubusercontent.com/...
    # update src: https://raw.githubusercontent.com/...
